@@ -22,6 +22,7 @@ import (
 	"github.com/containers/podman/v5/pkg/auth"
 	"github.com/containers/podman/v5/pkg/bindings"
 	"github.com/containers/podman/v5/pkg/domain/entities/types"
+	"github.com/containers/podman/v5/pkg/specgen"
 	"github.com/containers/podman/v5/pkg/util"
 	"github.com/containers/storage/pkg/fileutils"
 	"github.com/containers/storage/pkg/ioutils"
@@ -49,6 +50,42 @@ type BuildResponse struct {
 	Aux          json.RawMessage `json:"aux,omitempty"`
 }
 
+// Modify the build contexts that uses a local windows path. The windows path is
+// converted into the corresping guest path in the default Windows machine
+// (e.g. C:\test ==> /mnt/c/test).
+func convertAdditionalBuildContexts(additionalBuildContexts map[string]*define.AdditionalBuildContext) {
+	for _, context := range additionalBuildContexts {
+		if !context.IsImage && !context.IsURL {
+			path, err := specgen.ConvertWinMountPath(context.Value)
+			// It's not worth failing if the path can't be converted
+			if err == nil {
+				context.Value = path
+			}
+		}
+	}
+}
+
+// convertVolumeSrcPath converts windows paths in the HOST-DIR part of a volume
+// into the corresponding path in the default Windows machine.
+// (e.g. C:\test:/src/docs ==> /mnt/c/test:/src/docs).
+// If any error occurs while parsing the volume string, the original volume
+// string is returned.
+func convertVolumeSrcPath(volume string) string {
+	splitVol := specgen.SplitVolumeString(volume)
+	if len(splitVol) < 2 || len(splitVol) > 3 {
+		return volume
+	}
+	convertedSrcPath, err := specgen.ConvertWinMountPath(splitVol[0])
+	if err != nil {
+		return volume
+	}
+	if len(splitVol) == 2 {
+		return convertedSrcPath + ":" + splitVol[1]
+	} else {
+		return convertedSrcPath + ":" + splitVol[1] + ":" + splitVol[2]
+	}
+}
+
 // Build creates an image using a containerfile reference
 func Build(ctx context.Context, containerFiles []string, options types.BuildOptions) (*types.BuildReport, error) {
 	if options.CommonBuildOpts == nil {
@@ -90,6 +127,10 @@ func Build(ctx context.Context, containerFiles []string, options types.BuildOpti
 		params.Add("t", tag)
 	}
 	if additionalBuildContexts := options.AdditionalBuildContexts; len(additionalBuildContexts) > 0 {
+		// TODO: Additional build contexts should be packaged and sent as tar files
+		// For the time being we make our best to make them accessible on remote
+		// machines too (i.e. on macOS and Windows).
+		convertAdditionalBuildContexts(additionalBuildContexts)
 		additionalBuildContextMap, err := jsoniter.Marshal(additionalBuildContexts)
 		if err != nil {
 			return nil, err
@@ -239,6 +280,10 @@ func Build(ctx context.Context, containerFiles []string, options types.BuildOpti
 	if len(options.RusageLogFile) > 0 {
 		params.Set("rusagelogfile", options.RusageLogFile)
 	}
+
+	params.Set("retry", strconv.Itoa(options.MaxPullPushRetries))
+	params.Set("retry-delay", options.PullPushRetryDelay.String())
+
 	if len(options.Manifest) > 0 {
 		params.Set("manifest", options.Manifest)
 	}
@@ -281,6 +326,12 @@ func Build(ctx context.Context, containerFiles []string, options types.BuildOpti
 	if mem := options.CommonBuildOpts.Memory; mem > 0 {
 		params.Set("memory", strconv.Itoa(int(mem)))
 	}
+	switch options.CompatVolumes {
+	case imageTypes.OptionalBoolTrue:
+		params.Set("compatvolumes", "1")
+	case imageTypes.OptionalBoolFalse:
+		params.Set("compatvolumes", "0")
+	}
 	if options.NoCache {
 		params.Set("nocache", "1")
 	}
@@ -326,7 +377,7 @@ func Build(ctx context.Context, containerFiles []string, options types.BuildOpti
 	}
 
 	for _, volume := range options.CommonBuildOpts.Volumes {
-		params.Add("volume", volume)
+		params.Add("volume", convertVolumeSrcPath(volume))
 	}
 
 	for _, group := range options.GroupAdd {
