@@ -139,7 +139,7 @@ func GenerateSystemDFilesForVirtiofsMounts(mounts []machine.VirtIoFs) ([]ignitio
 	return unitFiles, nil
 }
 
-// StartGenericAppleVM is wrappered by apple provider methods and starts the vm
+// StartGenericAppleVM is wrapped by apple provider methods and starts the vm
 func StartGenericAppleVM(mc *vmconfigs.MachineConfig, cmdBinary string, bootloader vfConfig.Bootloader, endpoint string) (func() error, func() error, error) {
 	var (
 		ignitionSocket *define.VMFile
@@ -360,13 +360,19 @@ func CheckProcessRunning(processName string, pid int) error {
 		return fmt.Errorf("failed to read %s process status: %w", processName, err)
 	}
 	if pid > 0 {
-		// child exited
-		return fmt.Errorf("%s exited unexpectedly with exit code %d", processName, status.ExitStatus())
+		// Child exited, process is no longer running
+		if status.Exited() {
+			return fmt.Errorf("%s exited unexpectedly with exit code %d", processName, status.ExitStatus())
+		}
+		if status.Signaled() {
+			return fmt.Errorf("%s was terminated by signal: %s", processName, status.Signal().String())
+		}
+		return fmt.Errorf("%s exited unexpectedly", processName)
 	}
 	return nil
 }
 
-// StartGenericNetworking is wrappered by apple provider methods
+// StartGenericNetworking is wrapped by apple provider methods
 func StartGenericNetworking(mc *vmconfigs.MachineConfig, cmd *gvproxy.GvproxyCommand) error {
 	gvProxySock, err := mc.GVProxySocket()
 	if err != nil {
